pub fn find_matching_recursively_in_dir(
dir: &Path,
matching_file_fn: impl Fn(&DirEntry) -> bool,
skip_dir_fn: impl Fn(&DirEntry) -> bool,
) -> Result<Vec<PathBuf>>Expand description
Recursively find files matching a predicate (breadth-first)
Performs a breadth-first traversal starting at dir, skipping directories for which
skip_dir_fn returns true, and collecting file paths for which matching_file_fn returns true.
Errors
- Filesystem I/O error during traversal.